@@ -1,11 +1,11 @@
-#  File R/InitErgmm.fixed.R in package latentnet, part of the
-#  Statnet suite of packages for network analysis, https://statnet.org .
+#  File R/InitErgmm.fixed.R in package latentnet, part of the Statnet suite of
+#  packages for network analysis, https://statnet.org .
 #
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
+#  This software is distributed under the GPL-3 license.  It is free, open
+#  source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2024 Statnet Commons
+#  Copyright 2003-2025 Statnet Commons
 ################################################################################
 
 #' @importFrom statnet.common ult
@@ -94,9 +94,6 @@ nonlatent_error <- function(...){
 #'   It can be used explicitly to set prior mean and variance for the
 #'   intercept term.
 #'
-#'   This term differs from the \code{ergm}'s
-#'   \code{\link{edges-ergmTerm}} term if the network has self-loops.
-#'
 #' @usage
 #' # binary: 1(mean=0, var=9)
 #'
@@ -292,50 +289,25 @@ InitErgmm.loopfactor <- function (model, attrname, base=1, mean=0, var=9){
 
 #' @templateVar name latentcov
 #' @title Edge covariates for the latent model
-#' @description This term adds multiple covariates to the model, one
-#'   for each of (a subset of) the unique values of the
-#'   \code{attrname} attribute (or each combination of the attributes
-#'   given). Each of these covariates has \code{x[i,i]=1} if
-#'   \code{attrname(i)==l}, where \code{l} is that covariate's level,
-#'   and \code{x[i,j]=0} otherwise. To include all attribute values se
-#'   \code{base=0} -- because the sum of all such statistics equals
-#'   twice the number of self-loops and hence a linear dependency
-#'   would arise in any model also including \code{loops}. Thus, the
-#'   \code{base} argument tells which value(s) (numbered in order
-#'   according to the \code{sort} function) should be omitted. The
-#'   default value, \code{base=1}, means that the smallest (i.e.,
-#'   first in sorted order) attribute value is omitted. For example,
-#'   if the \dQuote{fruit} factor has levels \dQuote{orange},
-#'   \dQuote{apple}, \dQuote{banana}, and \dQuote{pear}, then to add
-#'   just two terms, one for \dQuote{apple} and one for \dQuote{pear},
-#'   then set \dQuote{banana} and \dQuote{orange} to the base
-#'   (remember to sort the values first) by using
-#'   \code{nodefactor("fruit", base=2:3)}. For an analogous term for
-#'   quantitative vertex attributes, see
-#'   \code{nodecov}.\code{attrname} is a character string giving the
-#'   name of a numeric (not categorical) attribute in the network's
-#'   vertex attribute list.  This term adds one covariate to the
-#'   model, for which \code{x[i,i]=attrname(i)} and \code{x[i,j]=0}
-#'   for \code{i!=j}.  This term only makes sense if the network has
-#'   self-loops.
+#' @description This term adds one statistic to the model, providing a covariate for each dyad.
 #'
 #'   \code{latentcov} can be called more than once, to model the
 #'   effects of multiple covariates. Note that some covariates can be
-#'   more conveniently specified using the following terms.
+#'   more conveniently specified using other terms.
 #'
 #' @usage
 #' # binary: latentcov(x, attrname=NULL, mean=0, var=9)
 #'
 #' # valued: latentcov(x, attrname=NULL, mean=0, var=9)
 #'
-#' @param x either a matrix of covariates on each pair of vertices, a
-#'   network, or an edge attribute.
-#' @param attrname optional argument to provide the name of the edge attribute.
+#' @template ergmTerm-x-attrname
 #'
 #' @template ergmTerm-latentnet-prior
 #'
 #' @template ergmTerm-general
 #' @template ergmTerm-latentnet-general
+#' @templateVar ergm_analogue edgecov
+#' @template ergmTerm-loops
 #'
 #' @concept dyad-independent
 #' @concept directed
@@ -350,31 +322,20 @@ InitErgmm.latentcov<-function (model, x, attrname=NULL,
   if (!(nargs() %in% 2:5))
     stop(paste("latentcov() model term expected between 1 and 4 arguments, got ", 
                                    nargs() - 1, sep = ""), call. = FALSE)
-  #Coerce x to an adjacency matrix
-  if(is.network(x)){
-    xm<-as.matrix.network(x,matrix.type="adjacency",attrname)
-    cn<-if(!is.null(attrname)) attrname else paste("network",length(model[["X"]])+1)
-  }else if(is.character(x)){
-    xm<-as.matrix.network(model[["Yg"]],matrix.type="adjacency",x)
-    cn<-x
-  }else{
-    xm<-as.matrix(x)
-    cn<-if(!is.null(attrname)) attrname else 
-				paste("latentcov", as.character(sys.call(0)[[3]]),	sep = ".")
-  }
+
+  # Create a fake check.ErgmTerm() list
+  a <- structure(list(x = x, attrname = attrname),
+                 exprs = list(x = substitute(x),
+                              attrname = substitute(attrname)))
+
+  l <- ergm_edgecov_args("latentcov", model[["Yg"]], a); xm <- l$xm; cn <- l$cn
 
   .ergmm.add.fixed(model, xm, mean, var, cn)
 }
 
 #' @templateVar name sendercov
 #' @title Sender covariate effect
-#' @description \emph{Deprecated for networks without self-loops. Use
-#'   \code{\link{nodeocov-ergmTerm}},
-#'   \code{\link{nodeofactor-ergmTerm}},
-#'   \code{\link{nodecov-ergmTerm}} or
-#'   \code{\link{nodefactor-ergmTerm}} instead.}
-#'
-#'   If the attribute is numeric, this term adds one covariate to the
+#' @description If the attribute is numeric, this term adds one covariate to the
 #'   model equaling \code{attrname(i)}. If the attribute is not
 #'   numeric or \code{force.factor==TRUE}, this term adds \eqn{p-1}
 #'   covariates to the model, where \eqn{p} is the number of unique
@@ -398,6 +359,8 @@ InitErgmm.latentcov<-function (model, x, attrname=NULL,
 #' @template ergmTerm-general
 #' @template ergmTerm-latentnet-general
 #' @template ergmTerm-directed
+#' @templateVar ergm_analogue nodeocov nodeofactor
+#' @template ergmTerm-loops
 #'
 #' @concept dyad-independent
 #' @concept directed
@@ -440,12 +403,7 @@ InitErgmm.sendercov<-function (model, attrname, force.factor=FALSE, mean=0, var=
 
 #' @templateVar name receivercov
 #' @title Receiver covariate effect
-#' @description \emph{Deprecated for networks without self-loops. Use
-#'   \code{\link{nodeicov-ergmTerm}},
-#'   \code{\link{nodeifactor-ergmTerm}},
-#'   \code{\link{nodecov-ergmTerm}} or
-#'   \code{\link{nodefactor-ergmTerm}} instead.}
-#'
+#' @description
 #'   If the attribute is numeric, this term adds one covariate to the
 #'   model equaling \code{attrname(i)}. If the attribute is not
 #'   numeric or \code{force.factor==TRUE}, this term adds \eqn{p-1}
@@ -470,6 +428,8 @@ InitErgmm.sendercov<-function (model, attrname, force.factor=FALSE, mean=0, var=
 #' @template ergmTerm-general
 #' @template ergmTerm-latentnet-general
 #' @template ergmTerm-directed
+#' @templateVar ergm_analogue nodeicov nodeifactor
+#' @template ergmTerm-loops
 #'
 #' @concept dyad-independent
 #' @concept directed
@@ -512,10 +472,7 @@ InitErgmm.receivercov<-function (model, attrname, force.factor=FALSE, mean=0, va
 
 #' @templateVar name socialitycov
 #' @title Sociality covariate effect
-#' @description \emph{Deprecated for networks without self-loops. Use
-#'   \code{\link{nodecov-ergmTerm}} or
-#'   \code{\link{nodefactor-ergmTerm}} instead.}
-#'
+#' @description
 #'   If the attribute is numeric, this term adds one covariate to the
 #'   model equaling \code{attrname(i)}. If the attribute is not
 #'   numeric or \code{force.factor==TRUE}, this term adds \eqn{p-1}
@@ -539,6 +496,8 @@ InitErgmm.receivercov<-function (model, attrname, force.factor=FALSE, mean=0, va
 #'
 #' @template ergmTerm-general
 #' @template ergmTerm-latentnet-general
+#' @templateVar ergm_analogue nodecov nodefactor
+#' @template ergmTerm-loops
 #'
 #' @concept dyad-independent
 #' @concept undirected
