@@ -1,11 +1,11 @@
-/*  File src/P_alloc.c in package latentnet, part of the
- *  Statnet suite of packages for network analysis, https://statnet.org .
+/*  File src/P_alloc.c in package latentnet, part of the Statnet suite of
+ *  packages for network analysis, https://statnet.org .
  *
- *  This software is distributed under the GPL-3 license.  It is free,
- *  open source, and has the attribution requirements (GPL Section 7) at
+ *  This software is distributed under the GPL-3 license.  It is free, open
+ *  source, and has the attribution requirements (GPL Section 7) at
  *  https://statnet.org/attribution .
  *
- *  Copyright 2003-2024 Statnet Commons
+ *  Copyright 2003-2025 Statnet Commons
  */
 /**********************************************************************/
 /* Routines for memory management similar in functionality to R_alloc */
@@ -28,7 +28,7 @@ PMemNode *PMemNodes=NULL;
 void *P_alloc(size_t nmemb, size_t size){
   Rprintf("P_alloc: ");
   P_print_alloc();
-  Rprintf(" --%uB-> ", (unsigned int) nmemb*size);
+  Rprintf(" --%zuB-> ", nmemb*size);
 
   PMemNode *memnode=(PMemNode *)calloc(1,sizeof(PMemNode));
   if(!memnode) return NULL;
